pub type Result<T> = Result<T, ProofError>;Expand description
Convenience alias for results that may fail with a ProofError.
Aliased Type
pub enum Result<T> {
Ok(T),
Err(ProofError),
}pub type Result<T> = Result<T, ProofError>;Convenience alias for results that may fail with a ProofError.
pub enum Result<T> {
Ok(T),
Err(ProofError),
}